@@ -4,14 +4,18 @@
 
 __author__ = """Stephen Wasilewski"""
 __email__ = 'stephanwaz@gmail.com'
-__version__ = '1.0.11'
+__version__ = '1.0.12'
 __all__ = ['plot', 'cl_plot']
 
 
 import matplotlib
 backend = matplotlib.get_backend()
 import clipt.plot as mplt
-matplotlib.use(backend)
+
+try:
+    matplotlib.use(backend)
+except ModuleNotFoundError:
+    pass
 
 
 def get_root(inside=True, pyenv=False):
